import QtQuick 1.1
import com.nokia.meego 1.0

Page {
    Rectangle {
        id: viewHeader
        height: 72
        width: parent ? parent.width : 0
        color: "orange"

        Text {
            id: headerText
            x: 16
            anchors.verticalCenter: parent.verticalCenter
            color: "white"
            font.pixelSize: 32
            text: "n-Siders - " +
                  selectRolls.model.get(selectRolls.selectedIndex).name +
                  "d" +
                  selectDie.model.get(selectDie.selectedIndex).value
        }

        Rectangle {
            height: 1
            width: parent.width
            anchors.bottom: parent.bottom
            color: "#10000000"
        }

        Rectangle {
            height: 1
            width: parent.width
            anchors.top: parent.bottom
            anchors.topMargin: 1
            color: "white"
        }
    }

    Rectangle {
        id: rollsSelect
        anchors.top: viewHeader.bottom
        anchors.topMargin: 1
        height: 72
        width: parent ? parent.width / 2 : 0
        color: "black"

        Text {
            id: rollsTitle
            x: 16
            anchors.verticalCenter: parent.verticalCenter
            color: "white"
            font.pixelSize: 24
            font.bold: true
            text: "Rolls:"
        }

        Text {
            anchors.left: rollsTitle.right
            anchors.leftMargin: 8
            anchors.verticalCenter: parent.verticalCenter
            color: "white"
            font.pixelSize: 24
            text: selectRolls.model.get(selectRolls.selectedIndex).name
        }

        Rectangle {
            height: 72
            width: 1
            anchors.left: parent.right
            color: "#10000000"
        }

        Rectangle {
            height: 72
            width: 1
            anchors.left: parent.right
            anchors.leftMargin: 1
            color: "white"
        }

        MouseArea {
            anchors.fill: parent
            onClicked: selectRolls.open()
            onPressed: parent.opacity = 0.8
            onReleased: parent.opacity = 1
        }

        ToolIcon {
            id: rollsSelectIcon
            anchors.right: parent.right
            anchors.verticalCenter: parent.verticalCenter
            platformIconId: "icon-m-textinput-combobox-arrow"
            onClicked: selectRolls.open()
        }
    }

    Rectangle {
        id: dieSelect
        anchors.top: viewHeader.bottom
        anchors.left: rollsSelect.right
        anchors.topMargin: 1
        anchors.leftMargin: 1
        height: 72
        width: parent ? parent.width / 2 : 0
        color: "black"

        Text {
            id: dieTitle
            x: 16
            anchors.verticalCenter: parent.verticalCenter
            color: "white"
            font.pixelSize: 24
            font.bold: true
            text: "Die:"
        }

        Text {
            anchors.left: dieTitle.right
            anchors.leftMargin: 8
            anchors.verticalCenter: parent.verticalCenter
            color: "white"
            font.pixelSize: 24
            text: selectDie.model.get(selectDie.selectedIndex).name
        }

        Rectangle {
            height: 72
            width: 1
            anchors.left: parent.left
            color: "#10000000"
        }

        MouseArea {
            anchors.fill: parent
            onClicked: selectDie.open()
            onPressed: parent.opacity = 0.8
            onReleased: parent.opacity = 1
        }

        ToolIcon {
            id: dieSelectIcon
            anchors.right: parent.right
            anchors.verticalCenter: parent.verticalCenter
            platformIconId: "icon-m-textinput-combobox-arrow"
            onClicked: selectDie.open()
        }
    }

    Column {
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.margins: 32
        anchors.top: dieSelect.bottom
        id: content
        spacing: 24

        // A row for the result.
        Row {
            anchors.horizontalCenter: parent.horizontalCenter
            height: 10
            spacing: 24
            Text {
                id: resultRolls
                font.pixelSize: 18
                text: ''
            }
        }

        // A row for the total.
        Row {
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.bottomMargin: 48
            height: 80
            spacing: 24
            Text {
                id: resultTotal
                font.pixelSize: 64
                text: ''
            }
        }

        // A row for the die roller button.
        Row {
            anchors.horizontalCenter: parent.horizontalCenter
            //spacing: 32

            Button {
                id: rollButton

                property int animationIndex: 0
                property string animationSequence: '|/-\\|/-\\|'
                function advanceAnimation()
                {
                    if (animationIndex == animationSequence.length)
                    {
                        animationIndex = 0;
                        animationTimer.stop();
                        rollDice();
                        rollButton.enabled = true;
                    }
                    else
                    {
                        rollButton.enabled = false;
                        resultRolls.text = '';
                        resultTotal.text = animationSequence[animationIndex];
                        animationIndex++;
                    }
                }

                Timer {
                    id: animationTimer
                    interval: 50
                    repeat: true
                    running: false
                    onTriggered: rollButton.advanceAnimation()
                }

                function rollDice()
                {
                    var times = selectRolls.model.get(
                                selectRolls.selectedIndex).name;
                    var die = selectDie.model.get(
                                selectDie.selectedIndex).value
                    var dieRoll = 0;
                    var total = 0;
                    var resultText = '';
                    for (var i = 0; i < times; i++)
                    {
                        dieRoll = Math.floor(Math.random() * die) + 1;
                        if (total > 0)
                            resultText += ' + ';
                        total += dieRoll;
                        resultText += dieRoll;
                    }
                    if (times < 2)
                        resultText = '';
                    resultRolls.text = resultText;
                    resultTotal.text = total;
                }

                text: "Roll the Die!"
                width: 300
                onClicked: animationTimer.start()
            }
        }
    }

    function refreshSettings()
    {
        resultRolls.text = '';
        resultTotal.text = '';
        if (selectRolls.model.get(selectRolls.selectedIndex).name > 1)
            rollButton.text = 'Roll the Dice!';
        else
            rollButton.text = 'Roll the Die!';
    }

    SelectionDialog {
        id: selectRolls
        model: ListModel {
            ListElement { name: "1" }
            ListElement { name: "2" }
            ListElement { name: "3" }
            ListElement { name: "4" }
            ListElement { name: "5" }
            ListElement { name: "6" }
            ListElement { name: "7" }
            ListElement { name: "8" }
            ListElement { name: "9" }
            ListElement { name: "10" }
        }
        selectedIndex: 0
        titleText: "Select Rolls"
        onSelectedIndexChanged: refreshSettings()
    }

    SelectionDialog {
        id: selectDie
        model: ListModel {
            ListElement { name: "2-sider"; value: 2 }
            ListElement { name: "3-sider"; value: 3 }
            ListElement { name: "4-sider"; value: 4 }
            ListElement { name: "6-sider"; value: 6 }
            ListElement { name: "8-sider"; value: 8 }
            ListElement { name: "10-sider"; value: 10 }
            ListElement { name: "12-sider"; value: 12 }
            ListElement { name: "16-sider"; value: 16 }
            ListElement { name: "20-sider"; value: 20 }
            ListElement { name: "24-sider"; value: 24 }
            ListElement { name: "100-sider"; value: 100 }
        }
        selectedIndex: 3
        titleText: "Select Die"
        onSelectedIndexChanged: refreshSettings()
    }
}
